/*
 * Copyright (C) 2007 LAAS/CNRS
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *    - Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *    - Redistributions in binary form must reproduce the above
 *      copyright notice, this list of conditions and the following
 *      disclaimer in the documentation and/or other materials provided
 *      with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT HOLDERS OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 */

#if !defined HATP_UNDESIRABLESTATEDATA_HH_
#define HATP_UNDESIRABLESTATEDATA_HH_

#include<iostream>
#include<string>
#include<vector>

#include "SocialRuleData.hh"

class UndesirableStateData : public SocialRuleData
{
protected:
	/**
	* the durations of interval in which the undesirable state appears
	* (this vector has a size equal to nb)
	*/
	std::vector<double> durations;

	/**
	* true if the undesirable state is still true at the end of the plan
	*/
	bool atEnd;

public:
	explicit UndesirableStateData(Substitution* argSubst, std::vector<double> const& argDurations, bool argAtEnd);
	std::vector<double> const& getDurations() const;
	bool getAtEnd() const;
	~UndesirableStateData();
};

/**
 * constructor : set subst to argSubst, nb to argNb, durations to argDurations,
 * atEnd to argAtEnd and totalDuration to argTotalDuration
 */
inline UndesirableStateData::UndesirableStateData(Substitution* argSubst, std::vector<double> const& argDurations, bool argAtEnd)
: SocialRuleData(argSubst, argDurations.size()), durations(argDurations), atEnd(argAtEnd)
{}

/**
 * return subst
 */
inline std::vector<double> const& UndesirableStateData::getDurations() const
{
	return durations;
}

/**
 * return atEnd
 */
inline bool UndesirableStateData::getAtEnd() const
{
	return atEnd;
}

/**
 * destructor: empty
 */
inline UndesirableStateData::~UndesirableStateData()
{
}

#endif
