#include<iostream>

#include "HTNBase.hh"

using namespace std;

/**
 * constructor by copying (defautTask is automatically set to an empty Task)
 */
HTNBase::HTNBase(HTNBase const& htnb) {
	map<string, Task*> tmp = htnb.getDatabase();
	for(map<string, Task*>::const_iterator it = tmp.begin() ; it!=tmp.end() ; ++it)
		database[it->first] = new Task(*(it->second));
}

/**
 * adds e in database, if there is already an Task with the same name as e
 * overwrites it (without freeing memory!)
 */
void HTNBase::add(Task* t) {
	if(t != NULL) database[t->getName()] = t;
	else cerr << "ERROR: trying to add an Task in the HTNBase, the Task pointer is NULL (operation ignored)" << endl;
}

/**
 * return true if there a task with name s in database
 */
bool HTNBase::existingTask(string const& s) const {
	return database.find(s) != database.end();
}

/**
 * set the belief management method for this HTN base
 */
void HTNBase::setBeliefMethod(BeliefMethod* bm) {
	this->beliefMethod = bm;
}

/**
 * set the belief management method for this HTN base
 */
BeliefMethod* HTNBase::getBeliefMethod() const {
	return this->beliefMethod;
}

/**
 * make a string from the HTNBase and return it
 */
string HTNBase::toString() const {
	string s = "***** Start HTNBase Printing *****\n";
	for(map<string,Task*>::const_iterator it=database.begin() ; it!=database.end() ; ++it)
		s += it->second->toString() + "\n";
	s += "***** End HTNBase Printing *****\n";
	return s;
}

/**
 * assignment operator ()make a copy of htnb2copy
 */
HTNBase& HTNBase::operator=(HTNBase const& htnb2copy) {
	// we empty database
	for(map<string, Task*>::iterator itD = database.begin() ; itD!=database.end() ; ++itD) delete itD->second;
	database.clear();
	// we complete database from htnb2copy database
	map<string, Task*> tmp = htnb2copy.getDatabase();
	for(map<string, Task*>::const_iterator it = tmp.begin() ; it!=tmp.end() ; ++it) database[it->first] = new Task(*(it->second));
	return *this;
}

/**
 * destructor: delete all Entities in database
 */
HTNBase::~HTNBase() {
	for(map<string,Task*>::iterator it=database.begin() ; it!=database.end() ; ++it)
		delete it->second;
}
