/*
 * Copyright (C) 2007 LAAS/CNRS
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *    - Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *    - Redistributions in binary form must reproduce the above
 *      copyright notice, this list of conditions and the following
 *      disclaimer in the documentation and/or other materials provided
 *      with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT HOLDERS OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 */

#include<iostream>

#include "WorldBaseReport.hh"

using namespace std;

/**
 * parse report and return data in a vector as <operator> <entity> <attribute> <value1> <value2>
 * if the report is not in a good form, print an error and return an empty vector
 */
vector<string> parseModificationReport(string const& report)
{
	if(boost::regex_match(report.c_str(), attributeModifREPORT)) {
		boost::smatch what;
		if(boost::regex_match(report, what, atom_changeREPORT)) { // atom attribute modification
			vector<string> vec1(5);
			vec1[0] = ATOM_CHANGE;
			vec1[1] = what[1];
			vec1[2] = what[3];
			vec1[3] = what[6];
			vec1[4] = what[8];
			return vec1;
		}
		else if(boost::regex_match(report, what, vector_addREPORT)) { // adding a value in a vector attribute
			vector<string> vec2(4);
			vec2[0] = VECTOR_ADD;
			vec2[1] = what[1];
			vec2[2] = what[3];
			vec2[3] = what[6];
			return vec2;
		}
		else if(boost::regex_match(report, what, vector_removeREPORT)) { // removing a value in a vector attribute
			vector<string> vec3(4);
			vec3[0] = VECTOR_REMOVE;
			vec3[1] = what[1];
			vec3[2] = what[3];
			vec3[3] = what[6];
			return vec3;
		}
	}
	cerr << "ERROR: when trying to parse a modification report from a WorldBaseReport, report \"" + report + "\" has a bad syntax." << endl;
	return vector<string>(0);
}

/**
 * parse report and return data in a vector as <operator> <entity> <attribute> <value1> <value2>, etc....
 * if the report is not in a good form, print an error and return an empty vector
 */
vector<string> parseTestReport(string const& report)
{
	if(boost::regex_match(report.c_str(), attributeTestREPORT)) {
		boost::smatch what;
		if(boost::regex_match(report, what, atom_test_equalREPORT)) { // atom attribute equal test
			vector<string> vec1(4);
			vec1[0] = ATOM_TEST_EQUAL;
			vec1[1] = what[1];
			vec1[2] = what[3];
			vec1[3] = what[6];
			return vec1;
		}
		else if(boost::regex_match(report, what, atom_test_diffREPORT)) { // atom attribute diff test
			vector<string> vec2(4);
			vec2[0] = ATOM_TEST_DIFF;
			vec2[1] = what[1];
			vec2[2] = what[3];
			vec2[3] = what[6];
			return vec2;
		}
		else if(boost::regex_match(report, what, vector_test_inREPORT)) { // vector attribute test value in
			vector<string> vec3(4);
			vec3[0] = VECTOR_TEST_IN;
			vec3[1] = what[1];
			vec3[2] = what[3];
			vec3[3] = what[6];
			return vec3;
		}
		else if(boost::regex_match(report, what, vector_test_not_inREPORT)) { // vector attribute test value not in
			vector<string> vec4(4);
			vec4[0] = VECTOR_TEST_NOT_IN;
			vec4[1] = what[1];
			vec4[2] = what[3];
			vec4[3] = what[6];
			return vec4;
		}
	}
	cerr << "ERROR: when trying to parse a test report from a WorldBaseReport, report \"" + report + "\" has a bad syntax." << endl;
	return vector<string>(0);
}
